<TeXmacs|1.99.9>

<style|source>

<\body>
  <active*|<\src-title>
    <src-package-dtd|manila-paper|1.0|manila-paper|1.0>

    <\src-purpose>
      Variant of the reddish theme for presentations and posters with pale
      blue background.
    </src-purpose>

    <src-copyright|2013--2019|Joris van der Hoeven>

    <\src-license>
      This software falls under the <hlink|GNU general public license,
      version 3 or later|$TEXMACS_PATH/LICENSE>. It comes WITHOUT ANY
      WARRANTY WHATSOEVER. You should have received a copy of the license
      which the software. If not, see <hlink|http://www.gnu.org/licenses/gpl-3.0.html|http://www.gnu.org/licenses/gpl-3.0.html>.
    </src-license>
  </src-title>>

  <use-package|manila-paper-combo>

  <apply-theme|manila-paper>
</body>

<\initial>
  <\collection>
    <associate|sfactor|7>
  </collection>
</initial>